@@ -60,11 +60,6 @@ const SpinnerBox = new Lang.Class({
                                           valign: Gtk.Align.CENTER });
         this.widget.add(this._spinner);
 
-        this._label = new Gtk.Label({ label: '<big><b>' + _("Loading…") + '</b></big>',
-                                      use_markup: true,
-                                      halign: Gtk.Align.CENTER,
-                                      valign: Gtk.Align.CENTER });
-        this.widget.add(this._label);
         this.widget.show_all();
     },
 
