@@ -32,9 +32,6 @@ void gd_queue_thumbnail_job_for_file_async (GFile *file,
 
 gboolean gd_queue_thumbnail_job_for_file_finish (GAsyncResult *res);
 
-void gd_gtk_tree_view_set_activate_on_single_click (GtkTreeView *tree_view,
-                                                    gboolean should_activate);
-
 const char *gd_filename_get_extension_offset (const char *filename);
 
 char *gd_filename_strip_extension (const char * filename_with_extension);
@@ -48,20 +45,9 @@ gchar *gd_iso8601_from_timestamp (gint64 timestamp);
 GIcon *gd_create_collection_icon (gint base_size,
                                   GList *pixbufs);
 
-GVariant *gd_create_variant_from_pixbuf (GdkPixbuf *pixbuf);
-
 void gd_ev_view_find_changed (EvView *view,
                               EvJobFind *job,
                               gint page);
 
-void gd_tracker_miner_manager_index_file_async (TrackerMinerManager *manager,
-                                                GFile *file,
-                                                GAsyncReadyCallback callback,
-                                                gpointer user_data);
-
-gboolean gd_tracker_miner_manager_index_file_finish (TrackerMinerManager *manager,
-                                                     GAsyncResult *result,
-                                                     GError **error);
-
 #endif /* __GD_UTILS_H__ */
                                   
